JsonCraftFunction class abstract

Implementers

Constructors

JsonCraftFunction()

Properties

hashCode int
The hash code for this object.
no setterinherited
regex RegExp
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String key, dynamic value, GetValueFromPathFunction getValue, ReplaceRecursiveFunction replaceRecursive, Map<String, String>? templates) Map<String, dynamic>
clearKey(String key) String
has(String key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited